
# Class: annotation


Biolink Model root class for entity annotations.

URI: [biolink:Annotation](https://w3id.org/biolink/vocab/Annotation)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[QuantityValue],[Attribute],[Annotation]^-[QuantityValue],[Annotation]^-[Attribute])](https://yuml.me/diagram/nofunky;dir:TB/class/[QuantityValue],[Attribute],[Annotation]^-[QuantityValue],[Annotation]^-[Attribute])

## Children

 * [Attribute](Attribute.md) - A property or characteristic of an entity. For example, an apple may have properties such as color, shape, age, crispiness. An environmental sample may have attributes such as depth, lat, long, material.
 * [QuantityValue](QuantityValue.md) - A value of an attribute that is quantitative and measurable, expressed as a combination of a unit and a numeric value

## Referenced by Class


## Attributes

